[pitivi] timeline: Exclude transitions when grouping
- From: Alexandru Băluț <alexbalut src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [pitivi] timeline: Exclude transitions when grouping
- Date: Fri, 24 Jun 2022 21:18:11 +0000 (UTC)
commit 2217a49d062d07b58f652b1a253921b784e192e6
Author: Alexandru Băluț <alexandru balut gmail com>
Date: Mon Jun 13 23:02:27 2022 +0200
timeline: Exclude transitions when grouping
Fixes #2500
pitivi/utils/timeline.py | 13 +++++++++----
1 file changed, 9 insertions(+), 4 deletions(-)
---
diff --git a/pitivi/utils/timeline.py b/pitivi/utils/timeline.py
index 4eb91d000..89f228416 100644
--- a/pitivi/utils/timeline.py
+++ b/pitivi/utils/timeline.py
@@ -217,11 +217,16 @@ class Selection(GObject.Object, Loggable):
have only non-serializable ancestors.
"""
toplevels = set()
- for obj in self._clips:
- if not obj.timeline:
- # The element has been removed from the timeline. Ignore it.
+ for ges_clip in self._clips:
+ if not ges_clip.timeline:
+ # The clip has been removed from the timeline. Ignore it.
continue
- toplevel = obj.get_toplevel_parent()
+
+ if isinstance(ges_clip, GES.Transition):
+ # The transitions are updated automatically, no need to group them etc.
+ continue
+
+ toplevel = ges_clip.get_toplevel_parent()
toplevels.add(toplevel)
group = GES.Group.new()
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]